#' Add material damage to a layer of assets
#'
#' @param asset sf object, asset layer.
#' @param vulnerability data.frame, vulnerability of elementary components.
#'
#' @return An sf object with damage informations added.
#' 
#' @export

add_damage_material = function(
    asset,
    vulnerability = floodam.campsite::elementary_vulnerability
) {
    # work only if all height classes ar identical
    breaks = sort(unique(unlist(vulnerability[c("h_min", "h_max")])))
    pitch = getOption("floodam.campsite")[["pitch"]]

    vulnerability[["breaks"]] = sprintf(
        "(%s,%s]",
        vulnerability[["h_min"]],
        vulnerability[["h_max"]]
    )
    vulnerability = vulnerability[c("elementary", "damage", "breaks")]
    names(vulnerability) = c("elementary", "dam_mat", "breaks")
    vulnerability[["elementary"]] = gsub(
        "[ -]",
        "_",
        vulnerability[["elementary"]]
    )
    vulnerability = stats::reshape(
        vulnerability,
        direction = "wide",
        idvar = "breaks",
        timevar = "elementary",
        sep = "_"
    )

    asset[["breaks"]] = cut(asset[["height"]], breaks)
    asset = merge(asset, vulnerability, all.x = TRUE)

    for (p in pitch) {
        d = sprintf("dam_mat_%s", p)
        n = sprintf("n_%s", p)
        asset[[d]] = asset[[d]] * asset[[n]]
    }

    asset[["dam_mat"]] = apply(
        sf::st_drop_geometry(asset[sprintf("dam_mat_%s", pitch)]),
        1,
        sum,
        na.rm = TRUE
    )
    return(asset)
}
