#' Estimate damage at campsite level
#' 
#' @description
#' The `estimate_damage()` function calculates the damage at campsite level.
#'
#' @param dataset sf object, asset layer.
#' @param dam character, which types of damage that should be estimated.
#' @param detail logical, should all subtypes of damage be estimated also.
#'
#' @return A data.frame of damage by camping.
#' 
#' @export

estimate_damage = function(
    dataset,
    dam = "dam_mat",
    detail = FALSE
) {
    if (detail == TRUE) {
        dam = grep(dam, names(dataset), value = TRUE)
    }
    result = stats::aggregate(
        units::drop_units(sf::st_drop_geometry(dataset[dam])),
        sf::st_drop_geometry(dataset["camping"]),
        sum,
        na.rm = TRUE
    )
    
    return(result)
}