## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk[["set"]](
  collapse = TRUE,
  comment = "#>"
)

## ----setup--------------------------------------------------------------------
library(sf)
library(floodam.campsite)
# devtools::load_all("../../floodam.campsite")

## ----campsite-----------------------------------------------------------------
campsite = data.table::fread(
    system.file(
        "extdata/dataset",
        "campsite.csv",
        package = "floodam.campsite"
    ),
    data.table = FALSE
)

## ----hydraulic----------------------------------------------------------------
hydraulic <- sf::read_sf(
    system.file(
        "extdata/dataset",
        "hydraulic.gpkg",
        package = "floodam.campsite"
    )
)

## ----vulnerability------------------------------------------------------------
elementary_vulnerability = data.table::fread(
    system.file(
        "extdata",
        "elementary_vulnerability.csv",
        package = "floodam.campsite"
    ),
    data.table = FALSE
)

## -----------------------------------------------------------------------------
# charger les données spatiales du camping au niveau 1 :
path_n1 = system.file(
    "extdata/dataset",
    "camping_n1.gpkg",
    package = "floodam.campsite"
)
c_n1 = load_campsite(path_n1, campsite, "u", hydraulic)

## -----------------------------------------------------------------------------
# charger les données spatiales du camping au niveau 2
path_n2 = system.file(
    "extdata/dataset",
    "camping_n2.gpkg",
    package = "floodam.campsite"
) 
c_n2 = load_campsite(path_n2, campsite, "z", hydraulic)

## -----------------------------------------------------------------------------
#charger les données niveau 3 camping
path_n3 = system.file(
    "extdata/dataset",
    "camping_n3.gpkg",
    package = "floodam.campsite"
) 
c_n3 = load_campsite(path_n3, campsite, "d", hydraulic)

## -----------------------------------------------------------------------------
# croiser les données hydrauliques et spatiales - niveau 1 :
c_n1_h = add_hydraulic(c_n1, hydraulic, treatment = "divide")

## -----------------------------------------------------------------------------
# croiser les données hydrauliques et spatiales - niveau 2 :
c_n2_h = add_hydraulic(c_n2, hydraulic, treatment = "divide")

## -----------------------------------------------------------------------------
# croiser les données hydrauliques et spatiales - niveau 3 :
c_n3 = add_hydraulic(c_n3, hydraulic)

## -----------------------------------------------------------------------------
# associer les coûts de remise en état à chaque niveau :
c_n1_h = add_damage_material(c_n1_h)
c_n2_h = add_damage_material(c_n2_h)
c_n3 = add_damage_material(c_n3)

## -----------------------------------------------------------------------------
# estimer les dommages matériels totaux :
estimate_damage(c_n1_h)
estimate_damage(c_n2_h)
estimate_damage(c_n3)

## -----------------------------------------------------------------------------
# estimer les dommages matériels des trois types d'emplacements :
estimate_damage(c_n1_h, detail = TRUE)
estimate_damage(c_n2_h, detail = TRUE)
estimate_damage(c_n3, detail = TRUE)

## ----damage-------------------------------------------------------------------
n1 = estimate_damage(c_n1_h, dam = "dam_mat", detail = TRUE)
knitr::kable(
    n1,
    row.names = FALSE
)

