## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk[["set"]](
  collapse = TRUE,
  comment = "#>"
)

## ----setup--------------------------------------------------------------------
library(knitr)
library(sf)
library(floodam.campsite)

## ----category-----------------------------------------------------------------
elementary_category = data.table::fread(
    system.file(
        "extdata",
        "elementary_category.csv",
        package = "floodam.campsite"
    ),
    data.table = FALSE
)


## -----------------------------------------------------------------------------
knitr::kable(
    floodam.campsite::elementary_category,
    row.names = FALSE,
    caption = "Visualisation des catégories de composantes élémentaires")


## ----campsite-----------------------------------------------------------------
campsite = data.table::fread(
    system.file(
        "extdata/dataset",
        "campsite.csv",
        package = "floodam.campsite"
    ),
    data.table = FALSE
)

campsite = campsite[
    order(campsite[["camping"]]),
    c("camping", getOption("floodam.campsite")[["pitch"]])
]
#camping_name = campsite[["camping"]][1]

## -----------------------------------------------------------------------------
knitr::kable(
    campsite,
    row.names = FALSE,
    align = "lccc",
    caption = "Visualisation des données sur les emplacements")


## ----camping_n1---------------------------------------------------------------
camping_n1 <- sf::read_sf(
    system.file(
        "extdata/dataset",
        "camping_n1.gpkg",
        package = "floodam.campsite"
    )
)

# visualisation du niveau cartographique 1 : 
plot(camping_n1["camping"], main = "niveau 1")

## ----camping_n2---------------------------------------------------------------
camping_n2 <- sf::read_sf(
    system.file(
        "extdata/dataset",
        "camping_n2.gpkg",
        package = "floodam.campsite"
    )
)

# visualisation du niveau cartographique 2 :
col = c(
    "emplacement nu" = "yellow",
    "equipement"     = "purple",
    "batiment"       = "brown",
    "mobil-home"     = "orange",    
    "chalet"         = "red"
)
plot(
    main = "niveau 2", camping_n2["category"],
    lwd = 0.5, col = col[camping_n2[["category"]]]
)
legend("bottomleft", legend = names(col), fill = col)

## ----camping_n3---------------------------------------------------------------
camping_n3 <- sf::read_sf(
    system.file(
        "extdata/dataset",
        "camping_n3.gpkg",
        package = "floodam.campsite"
    )
)

# visualisation du niveau cartographique 3 :
plot(
    main = "niveau 3", camping_n3["category"],
    lwd = 0.5, col = col[camping_n3[["category"]]]
)
legend("bottomleft", legend = names(col), fill = col)

## ----vulnerability------------------------------------------------------------
elementary_vulnerability = data.table::fread(
    system.file(
        "extdata",
        "elementary_vulnerability.csv",
        package = "floodam.campsite"
    ),
    data.table = FALSE
)

## -----------------------------------------------------------------------------
knitr::kable(
    floodam.campsite::elementary_vulnerability,
    row.names = FALSE,
    align = "cclllcc",
    caption = "Visualisation des données")

## ----hydraulic----------------------------------------------------------------
hydraulic <- sf::read_sf(
    system.file(
        "extdata/dataset",
        "hydraulic.gpkg",
        package = "floodam.campsite"
    )
)

# Visualisation des données hydrauliques 

    ## prise en compte d'un seul paramètre hydraulique : la hauteur d'eau 
    plot(hydraulic["height"], border = NA)

    ## paramètre non pris en compte pour estimer les dommages dans floodam.campsite, mais qui pourrait être intégré à l'avenir : la vitesse
    plot(hydraulic["velocity"], border = NA)

## -----------------------------------------------------------------------------
knitr::kable(
    hydraulic[1,],
    row.names = FALSE,
    #caption = "Visualisation des données hydrauliques"
    )

