test_that("Test importing camping.csv",
    {
        expect_no_error(
            dataset <- data.table::fread(
                system.file(
                    "extdata/dataset",
                    "campsite.csv",
                    package = "floodam.campsite"
                ),
                data.table = FALSE
            )
        )
        expect_s3_class(dataset, "data.frame")
        expect_identical(
            sort(names(dataset)),
            c("bare_pitch", "camping", "chalet", "mobil_home", "pitch")
        )
    }
)

test_that("Test importing hydraulic.gpkg",
    {
        expect_no_error(
            dataset <- sf::read_sf(
                system.file(
                    "extdata/dataset",
                    "hydraulic.gpkg",
                    package = "floodam.campsite"
                )
            )
        )
        expect_s3_class(dataset, "sf")
        expect_identical(
            sort(names(dataset)),
            c("geom", "height", "velocity")
        )
    }
)

test_that("Test loading camping_n1.gpkg",
    {
        campsite = data.table::fread(
            system.file(
                "extdata/dataset",
                "campsite.csv",
                package = "floodam.campsite"
            ),
            data.table = FALSE
        )
        campsite = campsite[
            order(campsite[["camping"]]),
            c("camping", getOption("floodam.campsite")[["pitch"]])
        ]
    
        hydraulic <- sf::read_sf(
            system.file(
                "extdata/dataset",
                "hydraulic.gpkg",
                package = "floodam.campsite"
            )
        )

        expect_no_error(
            dataset <- load_campsite(
                system.file(
                    "extdata/dataset",
                    "camping_n1.gpkg",
                    package = "floodam.campsite"
                ),
                campsite, "uniform", hydraulic
            )
        )
        expect_s3_class(dataset, "sf")
        expect_identical(
            sort(names(dataset)),
            c(
                "area", "camping", "category", "elementary", "geometry",
                "n_bare_pitch", "n_chalet", "n_mobil_home", "precision"
            )
        )

        expect_no_error(current <- estimate_pitch(dataset))
        expect_equal(current, campsite)

        expect_no_error(
            dataset <- add_hydraulic(dataset, hydraulic, treatment = "divide")
        )
        expect_s3_class(dataset, "sf")
        expect_identical(
            sort(names(dataset)),
            c(
                "area", "area_asset", "camping", "category", "elementary",
                "geometry", "height", "id_asset", "n_bare_pitch", "n_chalet",
                "n_mobil_home", "precision", "velocity"
            )
        )
        expect_no_error(current <- estimate_pitch(dataset))
        # expect_equal(current, campsite)
    }
)

test_that("Test loading camping_n2.gpkg",
    {
        campsite = data.table::fread(
            system.file(
                "extdata/dataset",
                "campsite.csv",
                package = "floodam.campsite"
            ),
            data.table = FALSE
        )
        campsite = campsite[
            order(campsite[["camping"]]),
            c("camping", getOption("floodam.campsite")[["pitch"]])
        ]

        hydraulic <- sf::read_sf(
            system.file(
                "extdata/dataset",
                "hydraulic.gpkg",
                package = "floodam.campsite"
            )
        )

        expect_no_error(
            dataset <- load_campsite(
                system.file(
                    "extdata/dataset",
                    "camping_n2.gpkg",
                    package = "floodam.campsite"
                ),
                campsite, "zonal", hydraulic
            )
        )
        expect_s3_class(dataset, "sf")
        expect_identical(
            sort(names(dataset)),
            c(
                "area", "camping", "category", "elementary", "geometry",
                "n_bare_pitch", "n_chalet", "n_mobil_home", "precision"
            )
        )

        expect_no_error(current <- estimate_pitch(dataset))
        expect_equal(current, campsite)

        expect_no_error(
            dataset <- add_hydraulic(dataset, hydraulic, treatment = "divide")
        )
        expect_s3_class(dataset, "sf")
        expect_identical(
            sort(names(dataset)),
            c(
                "area", "area_asset", "camping", "category", "elementary",
                "geometry", "height", "id_asset", "n_bare_pitch", "n_chalet",
                "n_mobil_home", "precision", "velocity"
            )
        )
        expect_no_error(current <- estimate_pitch(dataset))
    }
)

test_that("Test loading camping_n3.gpkg",
    {
        campsite = data.table::fread(
            system.file(
                "extdata/dataset",
                "campsite.csv",
                package = "floodam.campsite"
            ),
            data.table = FALSE
        )
        campsite = campsite[
            order(campsite[["camping"]]),
            c("camping", getOption("floodam.campsite")[["pitch"]])
        ]

        hydraulic = sf::read_sf(
            system.file(
                "extdata/dataset",
                "hydraulic.gpkg",
                package = "floodam.campsite"
            )
        )

        expect_no_error(
            dataset <- load_campsite(
                system.file(
                    "extdata/dataset",
                    "camping_n3.gpkg",
                    package = "floodam.campsite"
                ),
                campsite, "detail", hydraulic
            )
        )
        expect_s3_class(dataset, "sf")
        expect_identical(
            sort(names(dataset)),
            c(
                "area", "camping", "category", "elementary", "geometry",
                "n_bare_pitch", "n_chalet", "n_mobil_home", "precision"
            )
        )

        expect_no_error(current <- estimate_pitch(dataset))
        expect_equal(current, campsite)

        expect_no_error(
            dataset <- add_hydraulic(dataset, hydraulic, treatment = "max")
        )
        expect_s3_class(dataset, "sf")
        expect_identical(
            sort(names(dataset)),
            c(
                "area", "area_asset", "camping", "category", "elementary",
                "geometry", "height", "id_asset", "n_bare_pitch", "n_chalet",
                "n_mobil_home", "precision", "velocity"
            )
        )
        expect_no_error(current <- estimate_pitch(dataset))
    }
)
